Unavailable

Enum Unavailable 

pub enum Unavailable {}
The bus, line, and delay of a platform with no spidev or GPIO character device.

No value of it exists, so a LinuxRadio can be named on any platform and opened only on Linux.