decode

Function decode 

pub fn decode(text: &str) -> Result<Vec<u8>, DecodeError>
Decodes base64, with or without its padding.

Arguments

  • text - the base64 string.

Returns

The bytes it encodes.

Errors

Returns DecodeError for a character outside the alphabet, padding before the end, or a trailing group of one character.