pub struct Eui(/* private fields */);Expand description
A gateway’s unique identifier, the eight bytes it puts in every datagram it sends.
It is written from the host’s MAC address, usually with FF FE in the middle, which is
why a Raspberry Pi gateway’s identifier starts with the three bytes of its network
interface.
Examples
use pamoja_gateway::udp::Eui;
let gateway = Eui::from_hex("b827ebfffe010203").expect("sixteen hex digits");
assert_eq!(gateway.to_hex(), "b827ebfffe010203");
assert_eq!(gateway.bytes()[0], 0xB8);Implementations