PaOutput

Enum PaOutput 

pub enum PaOutput {
    Rfo,
    PaBoost,
}
Which amplifier output a module wires to its antenna, from Table 33.

Variants



Rfo

The high efficiency amplifier on RFO_LF or RFO_HF, -4 to +15 dBm.



PaBoost

The regulated amplifier on PA_BOOST, +2 to +17 dBm, or +20 dBm with the high power setting of Table 34. The RFM95W wires its antenna here.

Implementations

Source

impl PaOutput

pub const fn range_dbm(self) -> (i8, i8)

Returns the output powers the amplifier delivers.

Returns

The lowest and highest in dBm.