CommandStatus

Enum CommandStatus 

pub enum CommandStatus {
    DataAvailable,
    Timeout,
    ProcessingError,
    ExecutionFailure,
    TxDone,
    Other(u8),
}
The outcome of the last command, in bits 3 to 1 of the status byte, from Table 13-76.

Variants



DataAvailable

A packet was received and its data can be read (0x2).



Timeout

A transaction took too long and tripped the internal watchdog (0x3).



ProcessingError

The opcode was invalid or the parameters were the wrong length (0x4).



ExecutionFailure

The command was understood but could not be carried out (0x5).



TxDone

The transmission of the current packet ended (0x6).



Other(u8)

A value the datasheet leaves reserved (0x0, 0x1, 0x7).