pub struct RxBufferStatus {
pub payload_len: u8,
pub start: u8,
}Expand description
Where a received payload sits in the data buffer, from GetRxBufferStatus.
Fields
payload_len: u8The length of the last received payload in bytes.
start: u8The buffer offset of its first byte.
Implementations
Sourceimpl RxBufferStatus
impl RxBufferStatus
Sourcepub const fn from_bytes(bytes: [u8; 2]) -> RxBufferStatus
pub const fn from_bytes(bytes: [u8; 2]) -> RxBufferStatus