pub struct Query {
pub command: Command,
pub answer_len: usize,
}Expand description
A command that the chip answers in the same transaction.
Fields
command: CommandThe bytes to send, including the NOP bytes that precede the answer.
answer_len: usizeHow many bytes of answer to read after them.