SpidevBus

Struct SpidevBus 

pub struct SpidevBus(pub Spidev);
Spidev wrapper providing the embedded-hal SpiBus trait.

Use this struct when you require direct access to the underlying SPI bus, for example when you want to use GPIOs as software-controlled CS (chip-select) pins to share the bus with multiple devices, or because a driver requires the entire bus (for example to drive smart LEDs).

Do not use this struct if you’re accessing SPI devices that already appear in your device tree; you will not be able to drive CS pins that are already used by spidev as GPIOs. Instead use SpidevDevice.

This struct must still be created from a spidev::Spidev device, but there are two important notes:

  1. The CS pin associated with this spidev device will be driven whenever any device accesses this bus, so it should be an unconnected or unused pin.
  2. No other spidev device on the same bus may be used as long as this SpidevBus exists, as Linux will not do anything to ensure this bus has exclusive access.

It is recommended to use a dummy spidev device associated with an unused CS pin, and then use regular GPIOs as CS pins if required. If you are planning to share this bus using GPIOs, the embedded-hal-bus crate may be of interest.

If necessary, you can configure the underlying spidev::Spidev instance with the SPI_NO_CS flag set to prevent any CS pin activity.

Tuple Fields

0: Spidev

Implementations



impl SpidevBus

pub fn open<P>(path: P) -> Result<SpidevBus, SPIError>
where P: AsRef<Path>,

See [spidev::Spidev::open] for details.

The provided path must be the only device in use on its bus, and note its own CS pin will be asserted for all device access, so the path should be to a dummy device used only to access the underlying bus.

Methods from Deref<Target = Spidev>

pub fn inner(&self) -> &File

Get a reference to the underlying File object

pub fn configure(&mut self, options: &SpidevOptions) -> Result<(), Error>

Write the provided configuration to this device

pub fn query_configuration(&self) -> Result<SpidevOptions, Error>

Read the current configuration from this device

pub fn transfer( &self, transfer: &mut spi_ioc_transfer<'_, '_>, ) -> Result<(), Error>

Perform a single transfer

pub fn transfer_multiple( &self, transfers: &mut [spi_ioc_transfer<'_, '_>], ) -> Result<(), Error>

Perform multiple transfers in a single system call to the kernel

Chaining together multiple requests like this can reduce latency and be used for conveniently and efficient implementing some protocols without extra round trips back to userspace.