CdevPin

Struct CdevPin 

pub struct CdevPin(pub LineHandle, _);
Newtype around gpio_cdev::LineHandle that implements the embedded-hal traits

Tuple Fields

0: LineHandle

Implementations



impl CdevPin

pub fn new(handle: LineHandle) -> Result<CdevPin, Error>

See gpio_cdev::Line::request for details.

pub fn into_input_pin(self) -> Result<CdevPin, Error>

Set this pin to input mode

pub fn into_output_pin(self, state: PinState) -> Result<CdevPin, Error>

Set this pin to output mode

Methods from Deref<Target = LineHandle>

pub fn get_value(&self) -> Result<u8, Error>

Request the current state of this Line from the kernel

This call is expected to succeed for both input and output lines. It should be noted, however, that some drivers may not be able to give any useful information when the value is requested for an output line.

This value should be 0 or 1 which a “1” representing that the line is active. Usually this means that the line is at logic-level high but it could mean the opposite if the line has been marked as being ACTIVE_LOW.

pub fn set_value(&self, value: u8) -> Result<(), Error>

Request that the line be driven to the specified value

The value should be 0 or 1 with 1 representing a request to make the line “active”. Usually “active” means logic level high unless the line has been marked as ACTIVE_LOW.

Calling set_value on a line that is not an output will likely result in an error (from the kernel).

pub fn line(&self) -> &Line

Get the Line information associated with this handle.

pub fn flags(&self) -> LineRequestFlags

Get the flags with which this handle was created