pamoja_stepper_step

Function pamoja_stepper_step 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_stepper_step( stepper: *mut PamojaStepper, direction: PamojaStepDirection, ) -> u8
Advances a stepper one step and returns the coil pattern to apply.

Returns

The four-bit coil pattern, or 0 if stepper is null. The most significant of the four bits is the first coil.

Safety

stepper must be a live handle from pamoja_stepper_new, or null.