pamoja_readings_free

Function pamoja_readings_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_readings_free( readings: *mut PamojaReadings, )
Releases a decoded reading series.

Passing null is a no-op.

Safety

readings must be a handle from pamoja_codec_quantizer_decode that has not already been freed, or null. After this call it must not be used again.