pamoja_window_free

Function pamoja_window_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_window_free(window: *mut PamojaWindow)
Releases a rolling window handle.

Passing null is a no-op.

Safety

window must be a handle from pamoja_window_new that has not already been freed, or null. After this call it must not be used again.