pamoja_readings_data

Function pamoja_readings_data 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_readings_data( readings: *const PamojaReadings, ) -> *const f32
Returns a pointer to a decoded series of float readings.

Use pamoja_readings_len for the count. The pointer is valid until the handle is freed.

Returns

A pointer to the readings, or null if readings is null.

Safety

readings must be a live handle from pamoja_codec_quantizer_decode, or null.