word_bytes

Function word_bytes 

pub fn word_bytes(value: u16) -> [u8; 3]
Builds the three bytes that carry a 16-bit word with its CRC.

The inverse of word. The part only accepts written data that is followed by a correct CRC, so a write of any data word goes through this.

Arguments

  • value - the 16-bit word.

Returns

The word most-significant byte first, then its CRC.