pamoja_profile_from_json

Function pamoja_profile_from_json 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_profile_from_json( manifest: *const c_char, ) -> *mut PamojaProfile
Loads a profile from its JSON manifest.

Arguments

  • manifest - the manifest, as null-terminated UTF-8.

Returns

A handle the caller must release with pamoja_profile_free, or null if the manifest is malformed or manifest is null, with the reason available from pamoja_last_error_message.

Safety

manifest must be a valid null-terminated UTF-8 string for the duration of the call, or null.