milli_percent

Function milli_percent 

pub fn milli_percent(raw: u16) -> u32
Converts a raw humidity word to thousandths of a percent relative humidity.

This is the datasheet’s RH = 100 * S_RH / (2^16 - 1) in integer arithmetic, rounded to the nearest thousandth of a percent.

Arguments

  • raw - the 16-bit humidity word.

Returns

The relative humidity in thousandths of a percent, from 0 to 100000.