pamoja_audit_entry_free

Function pamoja_audit_entry_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_audit_entry_free( entry: *mut PamojaAuditEntry, )
Releases an entry handle.

Passing null is a no-op.

Safety

entry must be a handle from a call that produced one and that has not already been freed, or null. After this call it must not be used again.