pamoja_slip_decoder_free

Function pamoja_slip_decoder_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_slip_decoder_free( decoder: *mut PamojaSlipDecoder, )
Releases a SLIP decoder handle.

Passing null is a no-op.

Safety

decoder must be a handle from pamoja_slip_decoder_new that has not already been freed, or null. After this call it must not be used again.