pamoja_anomaly_free

Function pamoja_anomaly_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_anomaly_free( anomaly: *mut PamojaAnomaly, )
Releases an anomaly detector handle.

Passing null is a no-op.

Safety

anomaly must be a handle from pamoja_anomaly_new that has not already been freed, or null. After this call it must not be used again.