pamoja_calibration_free

Function pamoja_calibration_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_calibration_free( calibration: *mut PamojaCalibration, )
Releases a calibration handle.

Passing null is a no-op.

Safety

calibration must be a handle from pamoja_calibration_linear that has not already been freed, or null. After this call it must not be used again.