pamoja_transport_free

Function pamoja_transport_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_transport_free( transport: *mut PamojaTransport, )
Releases a transport handle.

Passing null is a no-op.

Safety

transport must be a handle that has not already been freed or consumed by a call that takes ownership, or null. After this call it must not be used again.