pamoja_replay_free

Function pamoja_replay_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_replay_free(replay: *mut PamojaReplay)
Releases a replay handle.

Passing null is a no-op.

Safety

replay must be a handle from pamoja_replay_new that has not already been freed, or null. After this call it must not be used again.