pamoja_bme280_calibration_free

Function pamoja_bme280_calibration_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_bme280_calibration_free( calibration: *mut PamojaBme280Calibration, )
Releases a BME280 calibration handle.

Passing null is a no-op.

Safety

calibration must be a handle from pamoja_bme280_calibration_new that has not already been freed, or null. After this call it must not be used again.