pamoja_transport_send

Function pamoja_transport_send 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_transport_send( transport: *mut PamojaTransport, topic: *const c_char, payload: *const u8, payload_len: usize, ) -> PamojaStatus
Sends a payload to a topic over a transport.

Arguments

  • transport - the transport to send over.
  • topic - the destination topic, as null-terminated UTF-8.
  • payload - the bytes to send.
  • payload_len - the length of payload.

Returns

PamojaStatus::Ok once the transport has taken the payload.

Safety

transport must be a live handle, topic a valid null-terminated UTF-8 string, and payload must point to at least payload_len readable bytes or be null when that length is 0.