pamoja_scd4x_write_frame

Function pamoja_scd4x_write_frame 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_scd4x_write_frame( command: u16, value: u16, out_bytes: *mut u8, ) -> PamojaStatus
Builds the five bytes that write a word to an SCD4x: command, word, CRC.

Returns

PamojaStatus::Ok on success, with the five bytes written to out_bytes, or PamojaStatus::InvalidArgument if out_bytes is null.

Safety

out_bytes must point to at least five writable bytes.