pamoja_mesh_frame_id

Function pamoja_mesh_frame_id 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_mesh_frame_id( frame: *const PamojaMeshFrame, ) -> u16
Returns the sequence number that identifies a packet from its source.

Returns

The sequence number, or 0 if frame is null.

Safety

frame must be a live handle from a call that produced one, or null.