pamoja_can_frame_is_remote

Function pamoja_can_frame_is_remote 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_can_frame_is_remote( frame: *const PamojaCanFrame, ) -> bool
Reports whether a frame is a remote transmission request.

Returns

true for a remote frame, false otherwise or for a null frame.

Safety

frame must be a live handle from one of the frame constructors, or null.