pamoja_sim_robot_free

Function pamoja_sim_robot_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_sim_robot_free( robot: *mut PamojaSimRobot, )
Releases a simulated robot handle.

Passing null is a no-op.

Safety

robot must be a handle from pamoja_sim_robot_new that has not already been freed, or null. After this call it must not be used again.