pamoja_session_free

Function pamoja_session_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_session_free( session: *mut PamojaSession, )
Releases a session handle.

Passing null is a no-op.

Safety

session must be a handle from pamoja_session_establish that has not already been freed, or null. After this call it must not be used again.