pamoja_string_free

Function pamoja_string_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_string_free(string: *mut PamojaString)
Releases a string handle.

Passing null is a no-op.

Safety

string must be a handle from a call that produced one and that has not already been freed, or null. After this call it must not be used again.