pamoja_debounce_free

Function pamoja_debounce_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_debounce_free( debounce: *mut PamojaDebounce, )
Releases a debouncer handle.

Passing null is a no-op.

Safety

debounce must be a handle from pamoja_debounce_new that has not already been freed, or null. After this call it must not be used again.