pamoja_stepper_new

Function pamoja_stepper_new 

#[unsafe(no_mangle)]
pub extern "C" fn pamoja_stepper_new( drive: PamojaStepDrive, ) -> *mut PamojaStepper
Creates a stepper at the start of a drive pattern, with its position at zero.

Returns

A new stepper the caller must release with pamoja_stepper_free.