pamoja_lora_plan_channel_block

Function pamoja_lora_plan_channel_block 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_lora_plan_channel_block( plan: *const PamojaLoraPlan, which: u32, index: u16, out_block: *mut PamojaLoraChannelBlock, ) -> PamojaStatus
Returns one of the plan’s channel blocks.

Arguments

Returns

PamojaStatus::Ok on success.

Errors

Returns PamojaStatus::InvalidArgument if either pointer is null, which is not one of the constants, or the index is past the end.

Safety

plan must be a live plan handle and out_block must point at writable storage for one PamojaLoraChannelBlock.