pamoja_keyexpr_is_canon

Function pamoja_keyexpr_is_canon 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_keyexpr_is_canon( key: *const c_char, ) -> bool
Reports whether a key expression is already in its canonical form.

Arguments

  • key - the expression to check, as null-terminated UTF-8.

Returns

true when the expression is canonical, or false if it is not or key is null.

Safety

key must be a valid null-terminated UTF-8 string for the duration of the call, or null.