pamoja_thermostat_free

Function pamoja_thermostat_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_thermostat_free( thermostat: *mut PamojaThermostat, )
Releases a thermostat handle.

Passing null is a no-op.

Safety

thermostat must be a handle from pamoja_thermostat_cooling that has not already been freed, or null. After this call it must not be used again.