pamoja_samples_free

Function pamoja_samples_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_samples_free( samples: *mut PamojaSamples, )
Releases a decoded sample series.

Passing null is a no-op.

Safety

samples must be a handle from pamoja_codec_decode_deltas that has not already been freed, or null. After this call it must not be used again.