pamoja_store_free

Function pamoja_store_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_store_free(store: *mut PamojaStore)
Releases a store handle.

Passing null is a no-op.

Safety

store must be a handle from a call that produced one and that has not already been freed or consumed, or null. After this call it must not be used again.