pamoja_string_len

Function pamoja_string_len 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_string_len( string: *const PamojaString, ) -> usize
Returns the length in bytes of a string, excluding its null terminator.

Returns

The byte length, or 0 if string is null.

Safety

string must be a live handle from a call that produced one, or null.