pamoja_stepper_free

Function pamoja_stepper_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_stepper_free( stepper: *mut PamojaStepper, )
Releases a stepper handle.

Passing null is a no-op.

Safety

stepper must be a handle from pamoja_stepper_new that has not already been freed, or null. After this call it must not be used again.