pamoja_store_append

Function pamoja_store_append 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_store_append( store: *mut PamojaStore, record: *const u8, record_len: usize, ) -> PamojaStatus
Adds a record to the end of a buffer.

Arguments

  • store - the buffer.
  • record - the bytes to hold.
  • record_len - the length of record.

Returns

PamojaStatus::Ok once the record is held.

Safety

store must be a live handle, and record must point to at least record_len readable bytes or be null when that length is 0.