pamoja_bmp280_calibration_free

Function pamoja_bmp280_calibration_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_bmp280_calibration_free( calibration: *mut PamojaBmp280Calibration, )
Releases a BMP280 calibration handle.

Passing null is a no-op.

Safety

calibration must be a handle from pamoja_bmp280_calibration_new that has not already been freed, or null. After this call it must not be used again.