pamoja_lorawan_rx_free

Function pamoja_lorawan_rx_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_lorawan_rx_free( rx: *mut PamojaLorawanRx, )
Releases a decoded frame handle.

Passing null is a no-op.

Safety

rx must be a handle from pamoja_lorawan_session_decode that has not already been freed, or null. After this call it must not be used again.