pamoja_updater_free

Function pamoja_updater_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_updater_free( updater: *mut PamojaUpdater, )
Releases an updater handle.

Passing null is a no-op.

Safety

updater must be a handle from pamoja_updater_new that has not already been freed, or null. After this call it must not be used again.