pamoja_mavlink_schema_at

Function pamoja_mavlink_schema_at 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_mavlink_schema_at( index: usize, out_schema: *mut *mut PamojaMavlinkSchema, ) -> PamojaStatus
Returns the shape of the message at a position in the built-in registry.

Arguments

Returns

PamojaStatus::Ok on success.

Errors

Returns PamojaStatus::InvalidArgument if out_schema is null or index is past the end of the registry.

Safety

out_schema must point at writable storage for one pointer.