bus_register

Function bus_register 

pub fn bus_register(microvolts: u32) -> u16
Builds the bus voltage register a monitor reports for a bus voltage.

The inverse of bus_microvolts. The same value serves as the alert limit for the bus over- and under-limit functions.

Arguments

  • microvolts - the bus voltage in microvolts.

Returns

The bus voltage register, at 1.25 mV per count.