pamoja_mavlink_verifier_new

Function pamoja_mavlink_verifier_new 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_mavlink_verifier_new( key: *const u8, out_verifier: *mut *mut PamojaMavlinkVerifier, ) -> PamojaStatus
Creates a verifier.

Arguments

  • key - the shared signing key, PAMOJA_MAVLINK_KEY_LEN bytes.
  • out_verifier - set to the handle on success, and to null otherwise.

Returns

PamojaStatus::Ok on success.

Errors

Returns PamojaStatus::InvalidArgument if either pointer is null.

Safety

key must point to PAMOJA_MAVLINK_KEY_LEN readable bytes and out_verifier must point at writable storage for one pointer.