pamoja_mesh_seen_free

Function pamoja_mesh_seen_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_mesh_seen_free( cache: *mut PamojaSeenCache, )
Releases a duplicate cache handle.

Passing null is a no-op.

Safety

cache must be a handle from pamoja_mesh_seen_new that has not already been freed, or null. After this call it must not be used again.