pamoja_mqtt_client_free

Function pamoja_mqtt_client_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_mqtt_client_free( client: *mut PamojaMqttClient, )
Releases an MQTT client handle.

Passing null is a no-op.

Safety

client must be a handle from pamoja_mqtt_client_new that has not already been freed, or null. After this call the handle must not be used again.