pamoja_tmp117_temperature_bytes

Function pamoja_tmp117_temperature_bytes 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_tmp117_temperature_bytes( raw: i16, out_bytes: *mut u8, ) -> PamojaStatus
Builds the two bytes a TMP117 sends for a temperature register.

Returns

PamojaStatus::Ok on success, with the two bytes written to out_bytes, or PamojaStatus::InvalidArgument if out_bytes is null.

Safety

out_bytes must point to at least two writable bytes.