pamoja_kit_deadband

Function pamoja_kit_deadband 

#[unsafe(no_mangle)]
pub extern "C" fn pamoja_kit_deadband( value: f32, center: f32, width: f32, ) -> f32
Suppresses movement within width of center, so noise does not act.

Returns

center while value is inside the band, and otherwise value shifted toward center by half the band width, so the output is continuous.