pamoja_pid_free

Function pamoja_pid_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_pid_free(pid: *mut PamojaPid)
Releases a PID controller handle.

Passing null is a no-op.

Safety

pid must be a handle from pamoja_pid_new that has not already been freed, or null. After this call it must not be used again.