pamoja_can_frame_free

Function pamoja_can_frame_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_can_frame_free( frame: *mut PamojaCanFrame, )
Releases a frame handle.

Passing null is a no-op.

Safety

frame must be a handle from one of the frame constructors that has not already been freed, or null. After this call it must not be used again.