pamoja_cobs_decoder_free

Function pamoja_cobs_decoder_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_cobs_decoder_free( decoder: *mut PamojaCobsDecoder, )
Releases a COBS decoder handle.

Passing null is a no-op.

Safety

decoder must be a handle from pamoja_cobs_decoder_new that has not already been freed, or null. After this call it must not be used again.