pamoja_depletion_free

Function pamoja_depletion_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_depletion_free( depletion: *mut PamojaDepletion, )
Releases a depletion estimator handle.

Passing null is a no-op.

Safety

depletion must be a handle from pamoja_depletion_new that has not already been freed, or null. After this call it must not be used again.