temperature_raw_from_milli_fahrenheit

Function temperature_raw_from_milli_fahrenheit 

pub fn temperature_raw_from_milli_fahrenheit(milli_fahrenheit: i32) -> u16
Builds the raw temperature word a part reports for a temperature in Fahrenheit.

The inverse of milli_fahrenheit, rounded to the nearest count and clamped to the part’s -49 °F to 266 °F output range.

Arguments

  • milli_fahrenheit - the temperature in millidegrees Fahrenheit.

Returns

The 16-bit temperature word.