pamoja_coap_client_free

Function pamoja_coap_client_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_coap_client_free( client: *mut PamojaCoapClient, )
Releases a CoAP endpoint handle.

Passing null is a no-op.

Safety

client must be a handle from pamoja_coap_client_new that has not already been freed, or null. After this call it must not be used again.