pamoja_lorawan_join_request_free

Function pamoja_lorawan_join_request_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_lorawan_join_request_free( request: *mut PamojaLorawanJoinRequest, )
Releases a verified join-request handle.

Passing null is a no-op.

Safety

request must be a handle from pamoja_lorawan_join_request_parse that has not already been freed, or null. After this call it must not be used again.