pamoja_samples_data

Function pamoja_samples_data 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_samples_data( samples: *const PamojaSamples, ) -> *const i64
Returns a pointer to a decoded series of integer samples.

Use pamoja_samples_len for the count. The pointer is valid until the handle is freed.

Returns

A pointer to the samples, or null if samples is null.

Safety

samples must be a live handle from pamoja_codec_decode_deltas, or null.