pamoja_updater_revert

Function pamoja_updater_revert 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_updater_revert( updater: *mut PamojaUpdater, out_slot: *mut u8, ) -> PamojaStatus
Fails the pending image and goes back to the confirmed one.

Arguments

  • updater - the updater.
  • out_slot - receives the slot to fall back to.

Returns

PamojaStatus::Ok on success, or a failure if there is nothing to fall back to.

Safety

updater must be a live handle from pamoja_updater_new, and out_slot must be writable or null.