pamoja_sht3x_temperature_raw_from_celsius

Function pamoja_sht3x_temperature_raw_from_celsius 

#[unsafe(no_mangle)]
pub extern "C" fn pamoja_sht3x_temperature_raw_from_celsius( celsius: f32, ) -> u16
Builds the SHT3x temperature word that decodes to a temperature in Celsius.

Returns

The raw word, saturating at the ends of the part’s range.