pamoja_frames_len

Function pamoja_frames_len 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_frames_len( frames: *const PamojaFrames, index: usize, ) -> usize
Returns the length in bytes of one frame’s payload.

Returns

The length, or 0 if frames is null or index is out of range.

Safety

frames must be a live handle from a decoder feed call, or null.