pamoja_recording_actuator_free

Function pamoja_recording_actuator_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_recording_actuator_free( actuator: *mut PamojaRecordingActuator, )
Releases a recording actuator handle.

Passing null is a no-op.

Safety

actuator must be a handle from pamoja_recording_actuator_new that has not already been freed, or null. After this call it must not be used again.