pamoja_smoother_free

Function pamoja_smoother_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_smoother_free( smoother: *mut PamojaSmoother, )
Releases a smoother handle.

Passing null is a no-op.

Safety

smoother must be a handle from pamoja_smoother_new that has not already been freed, or null. After this call it must not be used again.