max_duration_ms

Function max_duration_ms 

pub fn max_duration_ms(command: u16) -> Option<u16>
Returns the maximum command duration of a command word, in milliseconds.

This is the execution time column of Table 9, the time a caller waits after sending the command before issuing the read header or the next command.

Arguments

  • command - one of the command words.

Returns

The maximum duration in milliseconds, or None for the two start commands, whose duration the datasheet lists as not applicable, and for any word that is not a command.