pamoja_lorawan_device_free

Function pamoja_lorawan_device_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_lorawan_device_free( device: *mut PamojaLorawanDevice, )
Releases a device handle.

Passing null is a no-op.

Safety

device must be a handle from pamoja_lorawan_device_new that has not already been freed, or null. After this call it must not be used again.