pamoja_mesh_frame_bytes

Function pamoja_mesh_frame_bytes 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_mesh_frame_bytes( frame: *const PamojaMeshFrame, ) -> *const u8
Returns a pointer to the whole frame as it goes on the air.

Use pamoja_mesh_frame_bytes_len for the length. The pointer is valid until the frame is freed.

Returns

A pointer to the encoded frame, or null if frame is null.

Safety

frame must be a live handle from a call that produced one, or null.