pamoja_geofence_free

Function pamoja_geofence_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_geofence_free( geofence: *mut PamojaGeofence, )
Releases a geofence handle.

Passing null is a no-op.

Safety

geofence must be a handle from pamoja_geofence_new that has not already been freed, or null. After this call it must not be used again.