pamoja_ramp_free

Function pamoja_ramp_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_ramp_free(ramp: *mut PamojaRamp)
Releases a rate limiter handle.

Passing null is a no-op.

Safety

ramp must be a handle from pamoja_ramp_new that has not already been freed, or null. After this call it must not be used again.