pamoja_mavlink_frame_bytes

Function pamoja_mavlink_frame_bytes 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_mavlink_frame_bytes( frame: *const PamojaMavlinkFrame, out_len: *mut usize, ) -> *const u8
Returns a pointer to a frame’s bytes, ready to put on the wire.

The pointer is valid until the frame is released.

Arguments

  • frame - the frame to read.
  • out_len - set to the frame length in bytes.

Returns

A pointer to the frame, or null if either argument is null.

Safety

frame must be a live frame handle and out_len must point at writable storage for one length.