pamoja_audit_entry_from_bytes

Function pamoja_audit_entry_from_bytes 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_audit_entry_from_bytes( bytes: *const u8, len: usize, ) -> *mut PamojaAuditEntry
Reads an entry back from the bytes it was written as.

Arguments

  • bytes - the encoded entry.
  • len - the length of bytes.

Returns

A handle the caller must release with pamoja_audit_entry_free, or null if the bytes are not a well-formed entry.

Safety

bytes must point to at least len readable bytes, or be null when len is 0.