bus_microvolts

Function bus_microvolts 

pub fn bus_microvolts(raw: u16) -> u32
Decodes the bus voltage register to microvolts.

Bit 15 is always zero on the chip, since the bus voltage is positive only, and is ignored here.

Arguments

  • raw - the bus voltage register.

Returns

The bus voltage in microvolts, at 1.25 mV per count.