pamoja_mqtt_message_free

Function pamoja_mqtt_message_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_mqtt_message_free( message: *mut PamojaMqttMessage, )
Releases a message handle.

Passing null is a no-op.

Safety

message must be a handle from pamoja_mqtt_client_recv that has not already been freed, or null. After this call the handle must not be used again.