pamoja_sim_sensor_free

Function pamoja_sim_sensor_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_sim_sensor_free( sensor: *mut PamojaSimSensor, )
Releases a simulated sensor handle.

Passing null is a no-op.

Safety

sensor must be a handle from pamoja_sim_sensor_new that has not already been freed, or null. After this call it must not be used again.