pamoja_device_identity_free

Function pamoja_device_identity_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_device_identity_free( identity: *mut PamojaDeviceIdentity, )
Releases a device identity handle.

Passing null is a no-op.

Safety

identity must be a handle from pamoja_device_identity_new that has not already been freed, or null. After this call it must not be used again.