pamoja_reporter_free

Function pamoja_reporter_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_reporter_free( reporter: *mut PamojaReporter, )
Releases a reporter handle.

Passing null is a no-op.

Safety

reporter must be a handle from pamoja_reporter_new that has not already been freed, or null. After this call it must not be used again.