pamoja_tmp117_raw_from_celsius

Function pamoja_tmp117_raw_from_celsius 

#[unsafe(no_mangle)]
pub extern "C" fn pamoja_tmp117_raw_from_celsius(celsius: f32) -> i16
Builds the TMP117 temperature register that decodes to a temperature in Celsius.

Returns

The nearest register value, saturating at the ends of the part’s range.