pamoja_mavlink_schema_id

Function pamoja_mavlink_schema_id 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_mavlink_schema_id( schema: *const PamojaMavlinkSchema, ) -> u32
Returns the id of the message a schema describes.

Arguments

  • schema - the shape to read.

Returns

The message id, or 0 if schema is null.

Safety

schema must be a live schema handle or null.