pamoja_duty_cycle_new

Function pamoja_duty_cycle_new 

#[unsafe(no_mangle)]
pub extern "C" fn pamoja_duty_cycle_new( active_us: u64, sleep_us: u64, ) -> PamojaDutyCycle
Creates a duty cycle from the time awake and the time asleep.

Arguments

  • active_us - how long the node works each period, in microseconds.
  • sleep_us - how long it sleeps each period, in microseconds.

Returns

The duty cycle.