pamoja_router_free

Function pamoja_router_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_router_free(router: *mut PamojaRouter)
Releases a routing table handle.

Passing null is a no-op.

Safety

router must be a handle from pamoja_router_new that has not already been freed, or null. After this call it must not be used again.