pamoja_surge_free

Function pamoja_surge_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_surge_free(surge: *mut PamojaSurge)
Releases a surge detector handle.

Passing null is a no-op.

Safety

surge must be a handle from pamoja_surge_rising that has not already been freed, or null. After this call it must not be used again.