pamoja_thermostat_update

Function pamoja_thermostat_update 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_thermostat_update( thermostat: *mut PamojaThermostat, reading: f32, ) -> bool
Feeds a reading to a thermostat and returns whether the load should be on.

Returns

true while the load should run, or false if thermostat is null.

Safety

thermostat must be a live handle from a thermostat constructor, or null.