pamoja_trend_free

Function pamoja_trend_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_trend_free(trend: *mut PamojaTrend)
Releases a trend estimator handle.

Passing null is a no-op.

Safety

trend must be a handle from pamoja_trend_new that has not already been freed, or null. After this call it must not be used again.