pamoja_frames_free

Function pamoja_frames_free 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn pamoja_frames_free(frames: *mut PamojaFrames)
Releases a decoded frame set.

Passing null is a no-op.

Safety

frames must be a handle from a decoder feed call that has not already been freed, or null. After this call it must not be used again.