#[unsafe(no_mangle)]pub unsafe extern "C" fn pamoja_mesh_frame_free(
frame: *mut PamojaMeshFrame,
)Expand description
Releases a mesh frame handle.
Passing null is a no-op.
Safety
frame must be a handle from a call that produced one and that has not already
been freed, or null. After this call it must not be used again.