#[unsafe(no_mangle)]pub unsafe extern "C" fn pamoja_buffer_free(buffer: *mut PamojaBuffer)Expand description
Releases a buffer handle.
Passing null is a no-op.
Safety
buffer must be a handle from a pamoja call that produced one and that has
not already been freed, or null. After this call it must not be used again.