#[unsafe(no_mangle)]pub unsafe extern "C" fn pamoja_coap_client_send(
client: *mut PamojaCoapClient,
topic: *const c_char,
payload: *const u8,
payload_len: usize,
) -> PamojaStatusExpand description
Sends a payload to a resource path.
Arguments
client- the endpoint.topic- the resource path, as null-terminated UTF-8.payload- the bytes to send.payload_len- the length ofpayload.
Returns
PamojaStatus::Ok once the request has gone out.
Safety
client must be a live handle, topic a valid null-terminated UTF-8
string, and payload must point to at least payload_len readable bytes or
be null when that length is 0.