#[unsafe(no_mangle)]pub unsafe extern "C" fn pamoja_audit_entry_index( entry: *const PamojaAuditEntry, ) -> u64
Returns the position of an entry in its chain.
entry
The zero-based index, or 0 if entry is null.
entry must be a live handle from a call that produced one, or null.