pub fn data_ready(config: u16) -> boolExpand description
Returns whether the configuration register’s Data_Ready flag (bit 13) is set.
The flag is set when a conversion completes and cleared by reading either the temperature register or the configuration register.
Arguments
config- the configuration register.
Returns
true if a new temperature result is waiting.