pub fn verify_chain(public: &PublicIdentity, entries: &[Entry]) -> Result<()>Expand description
Verifies a whole chain of entries from the start against public.
Arguments
public- the public identity expected to have signed the log.entries- the log’s entries, oldest first.
Returns
Ok(()) if every entry is in sequence, correctly chained, and authentic.
Errors
Returns Error::Auth at the first entry that is out
of sequence, broken in the chain, or not authentically signed.