pub fn data_ready(word: u16) -> boolExpand description
Returns whether the data ready word reports a measurement waiting to be read.
Table 22: if the least significant 11 bits of the word are zero, data is not ready; otherwise a measurement is ready for read-out.
Arguments
word- the word read aftercommand::GET_DATA_READY_STATUS.
Returns
true if a measurement can be read.