#[unsafe(no_mangle)]pub unsafe extern "C" fn pamoja_mesh_frame_bytes_len( frame: *const PamojaMeshFrame, ) -> usize
Returns the length in bytes of the whole frame.
The encoded length, or 0 if frame is null.
frame
frame must be a live handle from a call that produced one, or null.