#[unsafe(no_mangle)]pub extern "C" fn pamoja_can_len_to_dlc(len: usize) -> u8
Returns the data length code that encodes a payload length.
The code for len, rounding up to the next length CAN-FD can carry.
len