#[unsafe(no_mangle)]pub extern "C" fn pamoja_coordinate_bearing_to(
from: PamojaCoordinate,
to: PamojaCoordinate,
) -> f64Expand description
Returns the initial bearing from one coordinate to another, in degrees.
#[unsafe(no_mangle)]pub extern "C" fn pamoja_coordinate_bearing_to(
from: PamojaCoordinate,
to: PamojaCoordinate,
) -> f64Returns the initial bearing from one coordinate to another, in degrees.