#[unsafe(no_mangle)]pub unsafe extern "C" fn pamoja_profile_free(
profile: *mut PamojaProfile,
)Expand description
Releases a profile handle.
Passing null is a no-op.
Safety
profile must be a handle from a call that produced one and that has not
already been freed, or null. After this call it must not be used again.