#[unsafe(no_mangle)]pub unsafe extern "C" fn pamoja_message_free(
message: *mut PamojaMessage,
)Expand description
Releases a message handle.
Passing null is a no-op.
Safety
message must be a handle from a call that produced one and that has not
already been freed, or null. After this call it must not be used again.