#[repr(C)]pub enum PamojaLinkCost {
Free = 0,
Metered = 1,
Expensive = 2,
Offline = 3,
}Expand description
What the link back to the network currently costs.
Variants
Free = 0
Bytes are effectively free, such as on wired power and ethernet.
Metered = 1
Bytes are paid for, such as on a cellular plan.
Expensive = 2
Bytes are scarce, such as on a satellite or long-range radio link.
Offline = 3
Nothing can be shipped at all.