#[unsafe(no_mangle)]pub extern "C" fn pamoja_cobs_decoder_new() -> *mut PamojaCobsDecoderExpand description
Creates a streaming COBS decoder.
Returns
A new decoder the caller must release with pamoja_cobs_decoder_free.
#[unsafe(no_mangle)]pub extern "C" fn pamoja_cobs_decoder_new() -> *mut PamojaCobsDecoderCreates a streaming COBS decoder.
A new decoder the caller must release with pamoja_cobs_decoder_free.