#[repr(C)]pub struct PamojaBoot {
pub action: PamojaBootAction,
pub slot: u8,
pub fallback: u8,
}Expand description
The decision a device made at boot, already recorded before it was returned.
Fields
action: PamojaBootActionWhat the bootloader should do.
slot: u8The image the decision is about, which for
PamojaBootAction::Reverted is the one that failed.
fallback: u8The slot to run. It is the same as slot for anything but
PamojaBootAction::Reverted.