#[unsafe(no_mangle)]pub unsafe extern "C" fn pamoja_audit_entry_free(
entry: *mut PamojaAuditEntry,
)Expand description
Releases an entry handle.
Passing null is a no-op.
Safety
entry must be a handle from a call that produced one and that has not
already been freed, or null. After this call it must not be used again.