pub fn power_register(microwatts: u32, current_lsb_microamps: u32) -> u16Expand description
Builds the power register a monitor reports for a power.
The inverse of power_microwatts. The same value serves as the alert limit for
the power over-limit function.
Arguments
microwatts- the power in microwatts.current_lsb_microamps- the current LSB the calibration register was set for.
Returns
The power register, or zero if current_lsb_microamps is zero.