pub enum MeshError {
FrameTooShort,
FrameTooLong,
PayloadTooLong,
UnsupportedVersion(u8),
CrcMismatch {
expected: u16,
found: u16,
},
}Expand description
What can go wrong building or reading a mesh frame.
Variants
FrameTooShort
A frame is shorter than the header and checksum a frame must at least contain.
FrameTooLong
A frame is larger than Frame::MAX_LEN.
PayloadTooLong
A payload is larger than Frame::MAX_PAYLOAD, so it
will not fit a single frame.
UnsupportedVersion(u8)
A received frame declares a protocol version this build does not understand.
CrcMismatch
A received frame’s checksum does not match its contents, so the frame is corrupt.