#[unsafe(no_mangle)]pub unsafe extern "C" fn pamoja_lorawan_session_free(
session: *mut PamojaLorawanSession,
)Expand description
Releases a session handle.
Passing null is a no-op.
Safety
session must be a handle from a call that produced one and that has not
already been freed, or null. After this call it must not be used again.