#[unsafe(no_mangle)]pub unsafe extern "C" fn pamoja_hdc1080_conversion_time_micros(
config: PamojaHdc1080Config,
out_micros: *mut u32,
) -> PamojaStatusExpand description
Returns how long to wait after triggering an HDC1080 in a configuration.
Returns
PamojaStatus::Ok on success, with *out_micros set, or
PamojaStatus::InvalidArgument if either resolution is not one the part
offers.
Safety
out_micros must point to a writable uint32_t.