#[unsafe(no_mangle)]pub unsafe extern "C" fn pamoja_audit_log_free(
log: *mut PamojaAuditLog,
)Expand description
Releases a log handle.
Passing null is a no-op.
Safety
log must be a handle from a call that produced one and that has not already
been freed, or null. After this call it must not be used again.