pub enum Oversampling {
Skipped,
X1,
X2,
X4,
X8,
X16,
}Expand description
An oversampling setting for the pressure or temperature measurement.
Each step adds one bit of output resolution, stored in the XLSB data register.
Variants
Skipped
The measurement is skipped and its data registers read SKIPPED_OUTPUT.
X1
A single sample, 16-bit output.
X2
Two samples, 17-bit output.
X4
Four samples, 18-bit output.
X8
Eight samples, 19-bit output.
X16
Sixteen samples, 20-bit output.
Implementations
Sourceimpl Oversampling
impl Oversampling
Sourcepub fn from_code(code: u8) -> Oversampling
pub fn from_code(code: u8) -> Oversampling