#[unsafe(no_mangle)]pub unsafe extern "C" fn pamoja_registers_data(
registers: *const PamojaRegisters,
) -> *const u16Expand description
Returns a pointer to the registers a device returned.
Use pamoja_registers_len for the count. The pointer is valid until the
handle is freed.
Returns
A pointer to the registers, or null if registers is null.
Safety
registers must be a live handle from pamoja_modbus_frame_registers, or
null.