#[repr(C)]pub enum PamojaPinPolarity {
ActiveHigh = 0,
ActiveLow = 1,
}Expand description
Whether a signal is asserted by a high or a low physical level.
Variants
ActiveHigh = 0
A high level means asserted.
ActiveLow = 1
A low level means asserted, the wiring of most buttons and relay boards.