pub trait Telemetry {
type Frame;
// Required method
async fn next_frame(&mut self) -> Result<Option<Self::Frame>>;
}Expand description
A device that emits a continuous stream of telemetry frames.
Required Associated Types
Required Methods
Sourceasync fn next_frame(&mut self) -> Result<Option<Self::Frame>>
async fn next_frame(&mut self) -> Result<Option<Self::Frame>>
Awaits the next telemetry frame.
Returns
Some(frame) when a frame is available, or None once the telemetry
stream has ended.
Errors
Returns Error::Transport if the telemetry
link fails while waiting.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".