#[unsafe(no_mangle)]pub extern "C" fn pamoja_tmp117_cycle_micros(
cycle: u8,
averaging: u8,
) -> u32Expand description
Returns how often a TMP117 updates its result for a cycle and averaging code.
Returns
The longer of the nominal cycle and the time the averaging takes.