#[unsafe(no_mangle)]pub extern "C" fn pamoja_slip_decoder_new() -> *mut PamojaSlipDecoderExpand description
Creates a streaming SLIP decoder.
Returns
A new decoder the caller must release with pamoja_slip_decoder_free.
#[unsafe(no_mangle)]pub extern "C" fn pamoja_slip_decoder_new() -> *mut PamojaSlipDecoderCreates a streaming SLIP decoder.
A new decoder the caller must release with pamoja_slip_decoder_free.