#[unsafe(no_mangle)]pub unsafe extern "C" fn pamoja_mavlink_schema_id( schema: *const PamojaMavlinkSchema, ) -> u32
Returns the id of the message a schema describes.
schema
The message id, or 0 if schema is null.
0
schema must be a live schema handle or null.