#[unsafe(no_mangle)]pub unsafe extern "C" fn pamoja_ladder_free(ladder: *mut PamojaLadder)Expand description
Releases a ladder handle, and the rungs and buffer it owns.
Passing null is a no-op.
Safety
ladder must be a handle from pamoja_ladder_new that has not already
been freed, or null. After this call it must not be used again.