pub struct Beacon {
pub data_rate: u8,
pub frequency_hz: u32,
pub ping_slot_frequency_hz: u32,
}Expand description
The Class B beacon settings a region broadcasts on.
Fields
data_rate: u8The data rate the beacon is sent at.
frequency_hz: u32The frequency the beacon is broadcast on, in hertz.
ping_slot_frequency_hz: u32The default ping-slot frequency, in hertz.