#[unsafe(no_mangle)]pub unsafe extern "C" fn pamoja_surge_update(
surge: *mut PamojaSurge,
value: f32,
out_delta: *mut f32,
) -> boolExpand description
Feeds a value to a surge detector.
Returns
true if this reading completed a qualifying step, having written the size of
the step to out_delta; false otherwise or if surge is null.
Safety
surge must be a live handle from a surge constructor, or null, and
out_delta must point to a writable float or be null.