#[repr(C)]pub enum PamojaPowerMode {
Active = 0,
Saver = 1,
Critical = 2,
}Expand description
What a node should be doing at the current state of charge.
Variants
Active = 0
Full duty, because the charge is healthy.
Saver = 1
Reduced duty, to conserve charge.
Critical = 2
Minimum duty, to stay alive as long as possible.