Function power_microwatts
Source pub fn power_microwatts(raw: u16, current_lsb_microamps: u32) -> u32
Decodes the power register to microwatts for a given current LSB.
The power LSB is fixed by the datasheet at twenty times the current LSB.
Arguments
raw - the power register.
current_lsb_microamps - the current LSB the calibration register was set for.
Returns
The power in microwatts.