#[unsafe(no_mangle)]pub unsafe extern "C" fn pamoja_can_frame_dlc( frame: *const PamojaCanFrame, ) -> u8
Returns a frame’s data length code, the length as it appears on the wire.
The code, or 0 if frame is null.
frame
frame must be a live handle from one of the frame constructors, or null.